Task: Natural Questions dataset
==================
Description: an open-domain question answering dataset.
The dataset is part of a challenge by Google AI.
Fore more information check the challenge [website](https://ai.google.com/research/NaturalQuestions).

Tags: #QA
